@@ -16,11 +16,11 @@
 import os
 import sys
 import time
-import types
 
 from oslo_log import log as logging
 from oslo_service import service
 import semantic_version
+import six
 
 from muranoagent import bunch
 from muranoagent.common import config
@@ -81,7 +81,7 @@ class MuranoAgent(service.Service):
             self._run(plan)
             return
 
-        msg_iterator.next()
+        next(msg_iterator)
 
     def _run(self, plan):
         try:
@@ -118,13 +118,13 @@ class MuranoAgent(service.Service):
             'port': rabbitmq.port,
             'virtual_host': rabbitmq.virtual_host,
             'ssl': rabbitmq.ssl,
-            'ca_certs': rabbitmq.ca_certs.strip() or None
+            'ca_certs': rabbitmq.ca_certs.strip() or None,
+            'insecure': rabbitmq.insecure
         }
         return messaging.MqClient(**connection_params)
 
     def _wait_plan(self):
         delay = 5
-        reconnect = False
         while True:
             try:
                 with self._create_rmq_client() as mq:
@@ -139,10 +139,6 @@ class MuranoAgent(service.Service):
                             if msg is not None:
                                 msg.ack()
                                 yield
-                                reconnect = True
-                            elif reconnect:
-                                reconnect = False
-                                break
             except KeyboardInterrupt:
                 break
             except Exception:
@@ -189,7 +185,7 @@ class MuranoAgent(service.Service):
 
         for attr in ('Scripts', 'Files', 'Options'):
             if attr in plan and not isinstance(
-                    plan[attr], types.DictionaryType):
+                    plan[attr], dict):
                 raise exc.IncorrectFormat(
                     2, '{0} is not a dictionary'.format(attr))
 
@@ -202,7 +198,7 @@ class MuranoAgent(service.Service):
     def _validate_script(self, name, script, plan_format_version, plan):
         for attr in ('Type', 'EntryPoint'):
             if attr not in script or not isinstance(script[attr],
-                                                    types.StringTypes):
+                                                    six.string_types):
                 raise exc.IncorrectFormat(
                     2, 'Incorrect {0} entry in script {1}'.format(
                         attr, name))
@@ -231,8 +227,7 @@ class MuranoAgent(service.Service):
                   "::" not in script['EntryPoint']):
                     raise exc.IncorrectFormat(
                         2, 'Wrong EntryPoint {0} for Puppet/Chef '
-                           'executors. :: needed'.format(name,
-                                                         script['EntryPoint']))
+                           'executors. :: needed'.format(script['EntryPoint']))
 
             for option in script['Options']:
                 if option in ('useBerkshelf', 'berksfilePath'):
@@ -250,7 +245,7 @@ class MuranoAgent(service.Service):
                 mns_error = ('Script {0} misses file {1}'.
                              format(name, additional_file))
                 if isinstance(additional_file, dict):
-                    if (additional_file.keys()[0] not in
+                    if (list(additional_file.keys())[0] not in
                             plan.get('Files', {}).keys()):
                         raise exc.IncorrectFormat(2, mns_error)
                 elif additional_file not in plan.get('Files', {}):
